@@ -88,21 +88,16 @@ sub io_filter (&@) {
     my $sub = shift;
     my %opt = @_;
     my $pid = do {
-	if (delete $opt{STDIN}) {
-	    open STDIN, '-|';
-	}
-	elsif (delete $opt{STDOUT}) {
-	    open STDOUT, '|-'
-	}
-	elsif (delete $opt{STDERR}) {
-	    open STDERR, '|-';
-	}
-	else {
-	    croak;
-	}
+	if    ($opt{STDIN})  { open STDIN,  '-|' }
+	elsif ($opt{STDOUT}) { open STDOUT, '|-' }
+	elsif ($opt{STDERR}) { open STDERR, '|-' }
+	else  { croak "Missing option" }
     } // die "fork: $!\n";;
     return $pid if $pid > 0;
-    $sub->(%opt);
+    if ($opt{STDERR}) {
+	open STDOUT, '>&', \*STDERR or die "dup: $!";
+    }
+    $sub->();
     exit 0;
 }
 
@@ -116,10 +111,10 @@ sub set {
 	    }
 	    use Getopt::EX::Func qw(parse_func);
 	    my $func = parse_func($filter);
-	    io_filter { $func->call($io => $opt{$io}) } %opt;
+	    io_filter { $func->call($io => $opt{$io}) } $io => 1;
 	}
 	else {
-	    io_filter { exec $filter or die "exec: $!\n" } %opt;
+	    io_filter { exec $filter or die "exec: $!\n" } $io => 1;
 	}
     }
 }
